#
# spec file for package form
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without doc

Name:           form
Version:        4.3.0
Release:        1.8
Summary:        A Symbolic Manipulation System
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/vermaseren/form/
Source0:        https://github.com/vermaseren/form/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE form-dont-use-DATE.patch badshah400@gmail.com -- Do not use __DATE__ in source code to avoid issues with reproducibility
Patch0:         form-dont-use-DATE.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  openmpi-macros-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
%if %{with doc}
BuildRequires:  texlive-tex4ht
BuildRequires:  tex(adjustbox.sty)
BuildRequires:  tex(amssymb.sty)
BuildRequires:  tex(calc.sty)
BuildRequires:  tex(caption.sty)
BuildRequires:  tex(courier.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(fixltx2e.sty)
BuildRequires:  tex(fontenc.sty)
BuildRequires:  tex(geometry.sty)
BuildRequires:  tex(graphicx.sty)
BuildRequires:  tex(helvet.sty)
BuildRequires:  tex(hyperref.sty)
BuildRequires:  tex(ifpdf.sty)
BuildRequires:  tex(inputenc.sty)
BuildRequires:  tex(makeidx.sty)
BuildRequires:  tex(multicol.sty)
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(natbib.sty)
BuildRequires:  tex(sectsty.sty)
BuildRequires:  tex(textcomp.sty)
BuildRequires:  tex(tocloft.sty)
BuildRequires:  tex(wasysym.sty)
BuildRequires:  tex(xcolor.sty)
%endif
Recommends:     %{name}-doc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# i586 compilation errors need to be investigated, disable for now
ExcludeArch:    %ix86
%openmpi_requires

%description
FORM is a Symbolic Manipulation System. It reads symbolic expressions from files
and executes symbolic/algebraic transformations upon them. The answers are
returned in a textual mathematical representation. As its landmark feature, the
size of the considered expressions in FORM is only limited by the available
disk space and not by the available RAM.

%package doc
Summary:        Additional documentation for %{name} - A Symbolic Manipulation System
Group:          Documentation/HTML

%description doc
FORM is a Symbolic Manipulation System. It reads symbolic expressions from files
and executes symbolic/algebraic transformations upon them. The answers are
returned in a textual mathematical representation. As its landmark feature, the
size of the considered expressions in FORM is only limited by the available
disk space and not by the available RAM.

This package provides additional documentation for %{name}.

%prep
%autosetup -p1

%build
%setup_openmpi

sed -i "s|-march=native||g" configure.ac

# Fix some TeX directives
sed -i "s/\\\\\([a-z]\)/\\1/g" configure.ac

autoreconf -fvi
%configure --enable-parform
%make_build

%if %{with doc}
# MAKE DOCUMENTATION
%make_build -C doc html pdf
%endif

%install
%make_install

%fdupes -s doc

%files
%license COPYING
%doc AUTHORS README.md
%if %{with doc}
%doc doc/manual/manual.pdf
%doc doc/manual/html/
%endif
%{_bindir}/form
%{_bindir}/tform
%{_bindir}/parform
%{_mandir}/man1/form.1%{ext_man}

%if %{with doc}
%files doc
%doc doc/doxygen/html/
%doc doc/devref/devref.pdf
%doc doc/devref/html/
%endif

%changelog
* Sun Nov 27 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.3.0:
  * Command-line options
  - Input filename - to use the standard input
    (gh#vermaseren/form#265).
  - Added -C flag to specify a custom log filename (b0e72a8).
  * Statements: Added allfloat option for `Format`
    (gh#vermaseren/form#216).
  * Functions: Added the Möbius function `moebius_` (0da2724).
  * Documentation
  - Added the FORM cookbook with practical examples
    (gh#vermaseren/form#409).
  - Documentation for features that were undocumented in the
    previous release (changed default setup parameters, `#System
  - e, SYSTEMERROR_, Print <filename>`).
  * Changed behaviour of `On fewerstatistics 0`
    (gh#vermaseren/form#285).
  * The setup `parameterContinuationLines` now affects all
    languages in addition to Fortran and 0 means infinity
    (gh#vermaseren/form#394).
  * The `Format` statement (except `Format <number>`) now does not
    reset the number of characters per line (dd1a71c).
  * Bug fixes
  - Crash for `#optimize` a trivial expression
    with Bracket (gh#vermaseren/form#7).
  - Exit statement in TFORM (gh#vermaseren/form#14).
  - Crash by `replace_` for nested functions
    (gh#vermaseren/form#307).
  - Disaster in adding many tables into a tablebase
    (gh#vermaseren/form#318).
  - Implicitly or autodeclared dimension of autodeclared indices
    (gh#vermaseren/form#324, gh#vermaseren/form#325,
    gh#vermaseren/form#405).
  - Crash when `ArgToExtraSymbol` is used for a function
    containing `g5_` (gh#vermaseren/form#340).
  - Incorrectly sorted `PolyRatFun` function arguments when
    `Argument` environment is used (gh#vermaseren/form#345).
  - Fixed `FactArg,(0)` (gh#vermaseren/form#353).
  - Unreplaced power signs by dictionaries
    (gh#vermaseren/form#358).
  - Inconsistent power signs with `Format` reduce
    (gh#vermaseren/form#359).
  - Denominators for nested denominator functions
    (gh#vermaseren/form#400).
- Add form-dont-use-DATE.patch -- Do not use __DATE__ in source
  code to avoid issues with reproducibility.
- Drop unused %%{name}-rpmlintrc file.
- Fix some TeX directives and re-enable documentation generation.
- Exclude 32-bit builds as they fail during make for hitherto
  not understood reasons.
* Thu Sep 30 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Use openmpi macros to always build with the default openmpi version.
* Fri Nov  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- Switch to using the newer openmpi2 instead of openmpi(1).
* Fri Mar 15 2019 Atri B <badshah400@gmail.com>
- Update to version 4.2.1:
  * See
    https://github.com/vermaseren/form/wiki/Release-Notes-Form-4.2.1
    for a full list of changes.
  * Bug fixes:
  - Replaced the obsolete ftime() function with clock_gettime()
    when the latter is available (gh#vermaseren/form#276)
  - Improved the algorithms of division and reminder for
    non-monic multivariate polynomials (gh#vermaseren/form#281)
  - Removed an inefficiency when many expressions are defined
  - Improved the merge sort inside memory based on Timsort
  - Fixed a bug that caused a pattern matching failure for
    restricted numbers in ex-Polyratfun (gh#vermaseren/form#55)
  - Fixed crashes in routines for gzip decompression
    (gh#vermaseren/form#95)
  - Fixed content_ for polynomials with constant terms
    (gh#vermaseren/form#185)
  - Fixed some portability issues (gh#vermaseren/form#217,
    gh#vermaseren/form#223)
  - Fixed corrupted characters from the prepreocessor calculator
    when the result is the most negative integer
    (gh#vermaseren/form#219)
  - Fixed a crash on accessing the first
    gh#vermaseren/form#factdollar factor of an integer
    (gh#vermaseren/form#222)
  - Fixed memory leaks in routines for gzip compression
    (gh#vermaseren/form#248)
  - Fixed a memory bug for local $-variables in TFORM
    (gh#vermaseren/form#253)
  - Fixed a bug that made gcd_ give wrong results
    (gh#vermaseren/form#258)
  - Fixed a bug in the polynomial GCD routine
    (gh#vermaseren/form#260)
  - Fixed a wrong "Division by zero" runtime error by mul_(x,0)
    (gh#vermaseren/form#261)
  - Fixed a bug that caused wrong results in code optimization
    (gh#vermaseren/form#272)
  - Fixed transform,addargs for the case that the result becomes
    0 (gh#vermaseren/form#277)
  - Fixed some bug in LHS patterns with poly(rat)fun and symbols
  - Fixed the problem that content_ did not handle functions
    properly
- Disable documentation due to LaTeX errors.
* Tue Jul 10 2018 bwiedemann@suse.com
- compile independent of build system CPU (boo#1100677)
* Wed Oct 25 2017 badshah400@gmail.com
- Setup MPI environment before building.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to version 4.2.0:
  + See
    https://github.com/vermaseren/form/wiki/Release-Notes---Form-4.2.0
    for list of changes.
- Drop form-devref-pdf.patch; incorporated upstream.
- Add BuildRequires on git, required to ascertain revision id.
* Fri Dec  9 2016 badshah400@gmail.com
- Initial package.
- Add form-devref-pdf.patch to fix a typo preventing devref PDF
  documentation from generating.
- Add %%{name}-rpmlintrc file to suppress warning regarding missing
  man pages: upstream doesn't supply these.
